==> jc-1.4.0.tar.gz: java/nio/ByteOrder.h <==
// public final class java.nio.ByteOrder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3d4356f2be8683db java_nio_ByteOrder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_ByteOrder_H_
#define _JC_java_nio_ByteOrder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_ByteOrder$object;

// Typedefs
typedef struct _jc_java_nio_ByteOrder$sub_refs	_jc_java_nio_ByteOrder$sub_refs;
typedef struct _jc_java_nio_ByteOrder$sub_nonrefs	_jc_java_nio_ByteOrder$sub_nonrefs;
typedef struct _jc_java_nio_ByteOrder$refs	_jc_java_nio_ByteOrder$refs;
typedef struct _jc_java_nio_ByteOrder$nonrefs	_jc_java_nio_ByteOrder$nonrefs;
typedef struct _jc_java_nio_ByteOrder$object	_jc_java_nio_ByteOrder$object;

typedef struct _jc_java_nio_ByteOrder$fields_struct	_jc_java_nio_ByteOrder$fields_struct;
typedef const struct _jc_java_nio_ByteOrder$vmethods	_jc_java_nio_ByteOrder$vmethods;
typedef const struct _jc_java_nio_ByteOrder$vtable	_jc_java_nio_ByteOrder$vtable;
typedef const struct _jc_java_nio_ByteOrder$vtype	_jc_java_nio_ByteOrder$vtype;

// Class fields structure
struct _jc_java_nio_ByteOrder$fields_struct {
	struct _jc_java_nio_ByteOrder$object	*BIG__5fENDIAN;
	struct _jc_java_nio_ByteOrder$object	*LITTLE__5fENDIAN;
};
extern _jc_java_nio_ByteOrder$fields_struct _jc_java_nio_ByteOrder$class_fields;

// Constructors
extern void _jc_java_nio_ByteOrder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_ByteOrder$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_nio_ByteOrder$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_nio_ByteOrder$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_ByteOrder$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_nio_ByteOrder$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_nio_ByteOrder$object *_jc_java_nio_ByteOrder$method$nativeOrder$3b65a4b669eeb622(_jc_env *);

// Virtual methods structure
struct _jc_java_nio_ByteOrder$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_nio_ByteOrder$object *);
};

// Vtable
struct _jc_java_nio_ByteOrder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_ByteOrder$vmethods	java_nio_ByteOrder;
};

// Vtype
struct _jc_java_nio_ByteOrder$vtype {
	_jc_type			type;
	_jc_java_nio_ByteOrder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_ByteOrder$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_ByteOrder$refs {
    _jc_java_nio_ByteOrder$sub_refs	java_nio_ByteOrder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_ByteOrder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_ByteOrder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_ByteOrder$sub_nonrefs	java_nio_ByteOrder;
};

// Object instance structure
struct _jc_java_nio_ByteOrder$object {
	_jc_java_nio_ByteOrder$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_ByteOrder$vtype	*vtype;
	_jc_java_nio_ByteOrder$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_ByteOrder$vtype _jc_java_nio_ByteOrder$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_ByteOrder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_ByteOrder$class_object;

#endif	/* _JC_java_nio_ByteOrder_H_ */

==> jc-1.4.6.tar.gz: java/nio/ByteOrder.h <==
// public final class java.nio.ByteOrder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3d4356f2be8683db java_nio_ByteOrder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_nio_ByteOrder_H_
#define _JC_java_nio_ByteOrder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_nio_ByteOrder$object;

// Typedefs
typedef struct _jc_java_nio_ByteOrder$sub_refs	_jc_java_nio_ByteOrder$sub_refs;
typedef struct _jc_java_nio_ByteOrder$sub_nonrefs	_jc_java_nio_ByteOrder$sub_nonrefs;
typedef struct _jc_java_nio_ByteOrder$refs	_jc_java_nio_ByteOrder$refs;
typedef struct _jc_java_nio_ByteOrder$nonrefs	_jc_java_nio_ByteOrder$nonrefs;
typedef struct _jc_java_nio_ByteOrder$object	_jc_java_nio_ByteOrder$object;

typedef struct _jc_java_nio_ByteOrder$fields_struct	_jc_java_nio_ByteOrder$fields_struct;
typedef const struct _jc_java_nio_ByteOrder$vmethods	_jc_java_nio_ByteOrder$vmethods;
typedef const struct _jc_java_nio_ByteOrder$vtable	_jc_java_nio_ByteOrder$vtable;
typedef const struct _jc_java_nio_ByteOrder$vtype	_jc_java_nio_ByteOrder$vtype;

// Class fields structure
struct _jc_java_nio_ByteOrder$fields_struct {
	struct _jc_java_nio_ByteOrder$object	*BIG__5fENDIAN;
	struct _jc_java_nio_ByteOrder$object	*LITTLE__5fENDIAN;
};
extern _jc_java_nio_ByteOrder$fields_struct _jc_java_nio_ByteOrder$class_fields;

// Constructors
extern void _jc_java_nio_ByteOrder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_ByteOrder$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_nio_ByteOrder$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_nio_ByteOrder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_ByteOrder$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_nio_ByteOrder$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_ByteOrder$object *_jc_java_nio_ByteOrder$method$nativeOrder$3b65a4b669eeb622(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_ByteOrder$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_nio_ByteOrder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_ByteOrder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_ByteOrder$vmethods	java_nio_ByteOrder;
};

// Vtype
struct _jc_java_nio_ByteOrder$vtype {
	_jc_type			type;
	_jc_java_nio_ByteOrder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_ByteOrder$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_ByteOrder$refs {
    _jc_java_nio_ByteOrder$sub_refs	java_nio_ByteOrder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_ByteOrder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_ByteOrder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_ByteOrder$sub_nonrefs	java_nio_ByteOrder;
};

// Object instance structure
struct _jc_java_nio_ByteOrder$object {
	_jc_java_nio_ByteOrder$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_ByteOrder$vtype	*vtype;
	_jc_java_nio_ByteOrder$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_ByteOrder$vtype _jc_java_nio_ByteOrder$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_ByteOrder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_ByteOrder$class_object;

#endif	/* _JC_java_nio_ByteOrder_H_ */
